==> ssp-center-api-0.2.54-20180626.053922-25-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotCheatReq.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.math.BigDecimal;
import java.util.Date;

// 广告位作弊信息
public class SlotCheatReq {
	private Long appId;                // appId
	private Long       slotId;
	private BigDecimal cheatingConsume; // 媒体作弊消耗
	private Integer    adviceRate;         // 建议分成比例
	private String     handleResult;        // 风控处理方式
	private Integer    cheatGrade;         // 作弊等级
	private Boolean    cheat;
	private Date       curDate;

	public Boolean getCheat() {
		return cheat;
	}

	public void setCheat(Boolean cheat) {
		this.cheat = cheat;
	}

	public Date getCurDate() {
		return curDate;
	}

	public void setCurDate(Date curDate) {
		this.curDate = curDate;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

	public BigDecimal getCheatingConsume() {
		return cheatingConsume;
	}

	public void setCheatingConsume(BigDecimal cheatingConsume) {
		this.cheatingConsume = cheatingConsume;
	}

	public Integer getAdviceRate() {
		return adviceRate;
	}

	public void setAdviceRate(Integer adviceRate) {
		this.adviceRate = adviceRate;
	}

	public String getHandleResult() {
		return handleResult;
	}

	public void setHandleResult(String handleResult) {
		this.handleResult = handleResult;
	}

	public Integer getCheatGrade() {
		return cheatGrade;
	}

	public void setCheatGrade(Integer cheatGrade) {
		this.cheatGrade = cheatGrade;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}
}

==> ssp-center-api-1.0.18-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotCheatReq.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

// 广告位作弊信息
public class SlotCheatReq implements Serializable {
	private static final long serialVersionUID = -8327465244753668610L;
	private Long appId;                // appId
	private Long       slotId;
	private BigDecimal cheatingConsume; // 媒体作弊消耗 ( 2020.12.17 确认广告线传的是广告位消耗 )
	private Integer    adviceRate;         // 建议分成比例
	private String     handleResult;        // 风控处理方式
	private Integer    cheatGrade;         // 作弊等级
	private Boolean    cheat;
	private Date       curDate;
	private boolean    ka;                 // 是否是ka媒体
	private Double cheatFeeRate;          // 作弊消耗占比=作弊消耗/消耗

	public Boolean getCheat() {
		return cheat;
	}

	public void setCheat(Boolean cheat) {
		this.cheat = cheat;
	}

	public Date getCurDate() {
		return curDate;
	}

	public void setCurDate(Date curDate) {
		this.curDate = curDate;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

	public BigDecimal getCheatingConsume() {
		return cheatingConsume;
	}

	public void setCheatingConsume(BigDecimal cheatingConsume) {
		this.cheatingConsume = cheatingConsume;
	}

	public Integer getAdviceRate() {
		return adviceRate;
	}

	public void setAdviceRate(Integer adviceRate) {
		this.adviceRate = adviceRate;
	}

	public String getHandleResult() {
		return handleResult;
	}

	public void setHandleResult(String handleResult) {
		this.handleResult = handleResult;
	}

	public Integer getCheatGrade() {
		return cheatGrade;
	}

	public void setCheatGrade(Integer cheatGrade) {
		this.cheatGrade = cheatGrade;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public boolean isKa() {
		return ka;
	}

	public void setKa(boolean ka) {
		this.ka = ka;
	}

	public Double getCheatFeeRate() {
		return cheatFeeRate;
	}

	public void setCheatFeeRate(Double cheatFeeRate) {
		this.cheatFeeRate = cheatFeeRate;
	}
}
